---
title: <span class="badge builder"></span> ExprTypeClassicConditionsConditionsQuery
---
# <span class="badge builder"></span> ExprTypeClassicConditionsConditionsQuery

## Constructor

```python
ExprTypeClassicConditionsConditionsQuery()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> expr.ExprTypeClassicConditionsConditionsQuery
```

### <span class="badge object-method"></span> params

```python
def params(params: list[str]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ExprTypeClassicConditionsConditionsQuery](./object-ExprTypeClassicConditionsConditionsQuery.md)
